#
# spec file for package sshfs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sshfs
Version:        3.7.4a
Release:        bp155.2.3.1
Summary:        Filesystem client based on SSH file transfer protocol
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://github.com/deadbeefsociety/sshfs
Source0:        https://github.com/deadbeefsociety/sshfs/releases/download/%{name}-%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/deadbeefsociety/sshfs/releases/download/%{name}-%{version}/%{name}-%{version}.tar.xz.asc
Source2:        sshfs.keyring
BuildRequires:  fuse3-devel >= 3.1.0
BuildRequires:  meson
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  pkgconfig(glib-2.0)
Requires:       fuse3 >= 3.1.0

%description
SSHFS is a filesystem client based on the SSH File Transfer Protocol.
Since most SSH servers already support this protocol it is very easy to
set up: i.e. on the server side there's nothing to do.	On the client
side mounting the filesystem is as easy as logging into the server with
openssh (ssh).

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%files
%license COPYING
%doc AUTHORS
%{_bindir}/*
%{_sbindir}/mount.fuse.sshfs
%{_sbindir}/mount.sshfs

%changelog
* Mon Oct  9 2023 Matej Cepl <mcepl@cepl.eu>
- Update to 3.7.4a:
  - Reverting PR #1 from user-reported bug bsc#1215574.
* Thu Sep 14 2023 Matej Cepl <mcepl@suse.com>
- Update to 3.7.4:
  - Support request size negotiation and increased throughput on
    high-latency connections
  - Supports connecting to vsock (7) via shfs -o vsock=CID:PORT
    @g-easy
  - README in markdown instead of rst
  - Various test fixes @neunenak
- Remove sshfs.keyring … upstream doesn’t provide checksums again
  (gh#deadbeefsociety/sshfs#12).
* Thu May 26 2022 Michael Ströder <michael@stroeder.com>
- sshfs 3.7.3:
  * Minor bugfixes.
  * This is the last release from the current maintainer.
    SSHFS is now no longer maintained.
- removed obsolete fix-typo-in-ssh_opts.patch
* Sun Oct 31 2021 munix9@googlemail.com
- Add fix-typo-in-ssh_opts.patch (boo#1191886)
  Required for kdeconnect-kde + openssh >= 8.8
* Mon Oct 25 2021 Andreas Stieger <andreas.stieger@gmx.de>
- sshfs 3.7.2:
  * Add a secondary check so if a mkdir request fails with EPERM an
    access request will be tried - returning EEXIST if the access
    was successful
* Mon Nov  9 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.7.1
  * Minor bugfixes
* Fri Jan  3 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.7.0
  * New max_conns option enables the use of multiple connections to
    improve responsiveness during large file transfers.
  * The buflimit workaround is now disabled by default.
    The corresponding bug in OpenSSH has been fixed in 2007
    (cf. https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=365541#37),
    so this shouldn't be needed anymore.
* Sun Nov  3 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.6.0
  * Added "-o direct_io" option.
    This option disables the use of page cache in kernel.
    This is useful for example if the file size is not known before reading it.
    For example if you mount /proc dir from a remote host without the direct_io
    option, the read always will return zero bytes instead of actual data.
  * Added --verbose option.
  * Fixed a number of compiler warnings.
  * Improved performance under OS X.
* Wed Apr 17 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.5.2
  * Fixed "-o idmap=user" to map both UID and GID on all OSs.
  * Fixed improper handling of sequential spaces spaces in
    "ssh_command" option
* Mon Mar 18 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.5.1
  * Documentation updates
  * Build system updates
  * Added "BindInterface" as valid "-o" option.
* Fri Dec  7 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.5.0
  * Fixed error code returned by rename(), allowing proper fallback.
  * Make utimens(NULL) result in timestamp "now" -- no more
    touched files dated 1970-01-01.
  * SSHFS now supports (or rather: ignores) some options that it
    may receive as result of being mounted from /etc/mtab.
    This includes things like user, netdev, or auto.
  * Dropped support for writeback caching (and, as a consequence,
    "unreliable append" operation). As of kernel 4.14, the FUSE
    module's writeback implementation is not compatible with
    network filesystems and there are no imminent plans to change
    that.
  * Add support for mounting from /etc/fstab
  * SSHFS now supports O_APPEND.
  * Fixed a crash due to a race condition when listing directory
    contents.
  * For improved backwards compatibility, SSHFS now also silently
    accepts the old -o cache_* options.
* Tue Oct  2 2018 astieger@suse.com
- sshfs 2.10:
  * Fix a crash due to a race condition when listing directory contents
  * Document limited hardlink support
  * Add support for more SSH options.
  * Drop support for the nodelay workaround
  * Drop support for the nodelaysrv workaround
    The same effect (enabling NODELAY on the server side and
    enabling X11 forwarding) can be achieved by explicitly passing
  - o ForwardX11
  * Remove support for -o workaround=all
* Tue Oct  2 2018 astieger@suse.com
- Add source signature and verify source signature
- clean up spec file
* Mon Jul 24 2017 mimi.vx@gmail.com
- update to 2.9
  * various bugfixes
* Sun May 28 2017 toms@opensuse.org
- Spec file:
  Correct URL from Sourceforge to GitHub (the SF URL is redirected
  to GH anyway)
* Tue Oct 18 2016 mimi.vx@gmail.com
- update to 2.8
- Added support for the "fsync" extension
* Thu Mar 17 2016 mimi.vx@gmail.com
- update to 2.7
- spec-cleaned spec file
  * Added -o cache_max_size=N option to let users tune the maximum size of the cache
  in number of entries.
  * Added -o cache_clean_interval=N and -o cache_min_clean_interval=N options to
  let users tune the cleaning behavior of the cache.
* Fri Oct  3 2014 dsterba@suse.cz
- update to 2.5
  * Add -o disable_hardlink option (debian bug #670926).
  * Optimize readdir by sending multiple requests in parallel.  Add -o
    sync_readdir to restore old behavior.
  * Map SSH2_FX_FAILURE to ENOTEMPTY for rmdir.
  * When checking root directory use LSTAT not STAT.  This prevents I/O error
    being returned after a successful mount if a symlink is mounted.
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Fri Mar 16 2012 tabraham@novell.com
- update to 2.4
  * Add "-oworkaround=fstat" for SFTP servers which don't support
    the FSTAT message.  Patch by: Percy Jahn
  * Remove "-oPreferredAuthentications" from ssh options if the
    "password_stdin" option is used.  Reported by E. Kuemmerle
  * Fix double free if reconnection races with request sending.
    Patch by E. Kuemmerle
  * Submit max 32k reads and writes to the sftp server.  Also don't
    limit the kernel to 64k reads and writes, rather split into 32k
    sized chunks and send them to the server all at once.  This is
    more efficient and less demanding from the server.  Reported by
    Ludovic Courtès.  Fix suggested by Niels Möller
  * Make chown respect the UID mapping policy.  Reported and tested
    by Vivenzio Pagliari
  * Add -o idmap=file, -o uidmap=FILE, -o gidmap=FILE. These options
    allow you to create a pair of local files, similar to /etc/passwd or
    /etc/group files from the remote server, and use those to remap all
    the given UIDs/GIDs.
  * Add -o slave. This option routes the sftp communication over stdin
    and stdout, bypassing SSH and network.
  * Make sure idmap files aren't writable by others otherwise, other
    local users could change the mapping, and gain access to things
    they shouldn't.  Patch by Mike Kelly
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Oct 11 2011 tabraham@novell.com
- updated to 2.3
  * Add hard link operation
  * Fix possible deadlock on reconnection
  * Fix cleanup when ssh connection is terminated to prevent
    sshfs hanging when the server is rebooted, for example
  * Set FD_CLOEXEC on fuse device to prevent deadlocks
  * Check mountpoint and fuse options before starting an ssh
    session
  * Allow mounting a single non-directory from the server
  * Add option 'delay_connect'
  * Print usage information and version to stdout, not stderr
* Tue Mar 22 2011 coolo@novell.com
- licenses package is about to die
* Wed Oct 29 2008 mszeredi@suse.de
- updated to version 2.2
  * Handle numerical IPv6 addresses enclosed in square brackets.
  * Fix error if username contains a comma character
* Fri Jul 25 2008 mszeredi@suse.de
- updated to version 2.1
  * Support password authentication with pam_mount
  * Support atomic renames if server is OpenSSH 4.9 or later
  * Support getting disk usage if server is OpenSSH 5.1 or later
  * Add man page
  * Improved ssh option support
  * Improved support for specifying a special ssh command
  * Fix bug that could cause corruption with append mode writes
  * Allow specifying an ssh config file
* Mon Dec 17 2007 mszeredi@suse.de
- updated to version 1.9
  * Fix crash when writing large files on SMP
  * Fill in st_ctime attribute
  * Add mount subtype support
  * Small optimizations
* Fri Aug 10 2007 bk@suse.de
- Add "Requires: fuse" to ensure that fuse is present (285101#c29)
* Thu May 17 2007 mszeredi@suse.de
- updated to version 1.8
  * Fix rare crashes due to uninitialized threading in glib
  * Fix memory leak in open
  * Fix crash when sem_wait() is interrupted (e.g. by gdb)
  * Fix caching when renaming a directory
  * Work around crash of sftp-server when its input buffer is full
  * Add option to work around performance problem with old ssh
    servers
  * Fix bug in follow_symlinks option
- Don't build sshnodelay.so, which is not needed any more with
  current ssh clients
* Thu Oct 12 2006 tiwai@suse.de
- update to version 1.7:
  * Add option 'follow_symlinks' to resolve symlinks on the server
  * Fix for sftp with login shell printing a banner
  * Check remote directory for existence before mounting
* Wed May 17 2006 schwab@suse.de
- Don't strip binaries.
* Tue May 16 2006 tiwai@suse.de
- updated to version 1.6
  * Fix segfault if remote host is down and reconnection is
    enabled
  * Fix bug in symlink transformation
  * Add workaround for broken truncate on old sftp servers
  * Memory copy optimizations
* Mon Feb 20 2006 cthiel@suse.de
- update to version 1.5
  * Add workaround (enabled by default) for ssh clients not setting
    TCP_NODELAY on the network connection.  Currently this is all known
    versions of openssh.  This may improve download speed in some
    circumstances
  * Use TCP_NODELAY socket option for direct connection.  This may improve
    download speed in some circumstances
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan 15 2006 cthiel@suse.de
- update to version 1.4
* Tue Nov 22 2005 msvec@suse.cz
- update to version 1.3
* Tue Sep 20 2005 cthiel@suse.de
- update to version 1.2
* Wed May 25 2005 tiwai@suse.de
- initial version: 1.1
